@@ -16,22 +16,18 @@ from ansurr.functions import check_quiet_print
 
 sys.tracebacklimit = 0
 
-#def natural_sort_key(s, _nsre=re.compile('([0-9]+)')):
-#    return [int(text) if text.isdigit() else text.lower()
-#            for text in _nsre.split(s)]
-
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
-
 def main():
 
     parser = argparse.ArgumentParser()
-    parser.add_argument("-l", "--ligands", help=" include free ligands when computing flexibility", action="store_true")
+    parser.add_argument("-l", "--lig", help=" include free ligands when computing flexibility", action="store_true")
     parser.add_argument("-n", "--nonstd", help=" include non-standard residues when computing flexibility", action="store_true")
-    parser.add_argument("-o", "--oligomer", help="combine chains into a single structure when calculating flexibility", action="store_true")
+    parser.add_argument("-o", "--olig", help="combine chains into a single structure when calculating flexibility", action="store_true")
     parser.add_argument("-q", "--quiet", help="supress output to the terminal", action="store_true")
     parser.add_argument("-p", "--pdb", type=str, help="input PDB file",required=True)
     parser.add_argument("-s", "--shifts", type=str, help="input shifts file in NEF format",required=True)
+    parser.add_argument("-r", "--reref", help="re-reference shifts using PANAV before calculating RCI (requires Java)",action="store_true")
     args = parser.parse_args()
 
     path_to_shifts = args.shifts
@@ -49,16 +45,15 @@ def main():
 
 
     check_quiet_print(args.quiet,"calculating RCI")
-    chain_output_rci = rci_nef.calc_RCI(path_to_shifts,output_dir+'/other_output/RCI/',quiet=args.quiet)
+    chain_output_rci = rci_nef.calc_RCI(path_to_shifts,output_dir+'/other_output/',panav=args.reref,quiet=args.quiet)
 
     check_quiet_print(args.quiet,'extracting models from '+path_to_pdb)
-    pdbs,args.oligomer  = rigidipy.extract_pdb(path_to_pdb,output_dir,freeligands=args.ligands,nonstandardres=args.nonstd,oligomers=args.oligomer,quiet=args.quiet)
+    pdbs,args.oligomer  = rigidipy.extract_pdb(path_to_pdb,output_dir,freeligands=args.lig,nonstandardres=args.nonstd,oligomers=args.olig,quiet=args.quiet)
     if len(pdbs) > 0:
         check_quiet_print(args.quiet,' -> extracted '+str(len(pdbs))+' model(s)')
     else:
         check_quiet_print(args.quiet,' -> CRITICAL ERROR failed to extract any models, exiting')
-        sys.exit()
-
+        sys.exit(1)
 
     check_quiet_print(args.quiet,'computing the flexibility of each model')
     chain_output_rigidity = {}
@@ -83,7 +78,7 @@ def main():
 
     if len(glob.glob(output_dir+'/other_output/FIRST/*.decomp')) == 0: # check FIRST worked
         check_quiet_print(args.quiet,' -> CRITICAL ERROR FIRST failed to run for any models, exiting')
-        sys.exit(0)
+        sys.exit(1)
 
     if args.oligomer:
         for pdb in glob.glob(output_dir+"/other_output/FIRST/*.decomp"):
@@ -101,14 +96,10 @@ def main():
     decomps = glob.glob(output_dir+'/other_output/FIRST/*.decomp')
 
     check_quiet_print(args.quiet,'computing ANSURR scores')
-    
-    #for decomp in sorted(decomps,key=natsort):
-    #    for rci in glob.glob(output_dir+'/other_output/RCI/*.rci'):
-    #        compare.compare_rci_rigidity(decomp,rci,output_dir+'/ANSURR_output/')
 
     for chain in chain_output_rigidity:
         for rigidity in sorted(chain_output_rigidity[chain],key=natsort):
-            if chain != ' ':
+            if chain in chain_output_rci:
                 for rci in sorted(chain_output_rci[chain],key=natsort):
                     compare.compare_rci_rigidity(rigidity,rci,output_dir+'/ANSURR_output/',quiet=args.quiet)
             else:
